Struct nvim_rs::rpc::handler::Dummy [−][src]
The dummy handler defaults to doing nothing with a notification, and returning a generic error for a request. It can be used if a plugin only wants to send requests to neovim and get responses, but not handle any notifications or requests.
Implementations